@@ -162,6 +162,16 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		self.connect(self.ui.wildness,
 			QtCore.SIGNAL("valueChanged(double)"),
 			lambda x: self.ui.wildslide.setValue(int(x * 10)))
+		self.connect(self.ui.copyprogression,
+			QtCore.SIGNAL("clicked()"),
+			self.copy_progression)
+		self.connect(self.ui.exportprogressions,
+			QtCore.SIGNAL("clicked()"),
+			self.export_progression)
+		self.connect(self.ui.importprogression,
+			QtCore.SIGNAL("clicked()"),
+			self.import_progression)
+
 
 	def set_defaults(self):
 
@@ -217,6 +227,57 @@ class ImproviserMainWindow(QtGui.QMainWindow):
 		if i >= 0:
 			self.ui.progressions.takeItem(i)
 
+	def copy_progression(self):
+		i = self.ui.progressions.currentRow()
+		if i >= 0:
+			self.ui.progressions.addItem(self.ui.progressions.item(i).text())
+
+	def import_progression(self):
+		h = "/home"
+		if 'HOME' in environ:
+			h = environ["HOME"]
+		f = QtGui.QFileDialog()
+		s = f.getOpenFileName(self, "Load progressions.",
+				h, "Progressions (*.prg)")
+		if s != "":
+			try:
+				fp = open(s, "r")
+				for x in fp.readlines():
+					prog = x.split(",")
+					for p in prog:
+						try:
+							r = Options.parse_progression(p)
+							self.ui.progressions.addItem(p)
+						except:
+							pass
+				fp.close()
+			except Options.OptionError, err:
+				self.set_status("Error: " + str(err))
+
+
+	def export_progression(self):
+		h = "/home"
+		if 'HOME' in environ:
+			h = environ["HOME"]
+		prog = self.get_progressions()
+		if prog == "":
+			return 
+		
+		f = QtGui.QFileDialog()
+		s = str(f.getSaveFileName(self, "Save progressions.",
+				h, "Progressions (*.prg)"))
+		if s != "":
+			if s[-4:].lower() != ".prg":
+				filename = s + ".prg"
+			else:
+				filename = s
+			try:
+				fp = open(filename, "w")
+				fp.write(prog)
+				fp.close()
+			except IOError:
+				self.set_status("Error: Couldn't open file for writing")
+
 	def add_instrument(self):
 		self.ui.instruments.addItem(self.ui.instrumentcombo.currentText())
 		self.ui.instruments.setCurrentRow(int(self.ui.instruments.count()) -1)
