@@ -1,6 +1,8 @@
 from PyQt4 import QtCore, QtGui
 from qtGUI.preferencesDialog import Ui_preferencesDialog
 from os import environ, path
+import urllib
+import md5
 
 class PreferencesDialog(QtGui.QDialog):
 
@@ -73,6 +75,21 @@ class PreferencesDialog(QtGui.QDialog):
 				pass
 
 
+	def login(self):
+		return True
+		params = urllib.urlencode({"name": str(self.ui.username.text()),
+			"pass": md5.new(str(self.ui.password.text())).digest()})
+		try:
+			f = urllib.urlopen("http://localhost/improviser/login.php?%s" % params)
+		except:
+			return False
+		res = f.read()
+		f.close()
+		if res == "OK":
+			return True
+		return False
+
+
 	def toggle_enabled(self):
 		if self.ui.no_fluidsynth.isChecked():
 			self.ui.browsebutton.enabled()
@@ -85,15 +102,20 @@ class PreferencesDialog(QtGui.QDialog):
 		soundfont = str(self.ui.soundfont.text())
 		driver = str(self.ui.driver.currentText())
 		no_fluidsynth = int(self.ui.no_fluidsynth.isChecked())
+		self.try_save_file()
+
+		params = { "username": str(self.ui.username.text()),
+			   "password": str(self.ui.password.text()),
+			   "login": self.login() }
 
 		if no_fluidsynth:
-			self.try_save_file()
-			self.show_main()
+			self.show_main(params)
 			self.reject()
 		else:
 			if soundfont != "":
-				self.try_save_file()
-				self.show_main(False, soundfont, driver)
+				params["soundfont"] = soundfont
+				params["driver"] = driver
+				self.show_main(params)
 				self.reject()
 
 	def load_dialog(self):
